_`umbra.components.factory.componentsManagerUi.models`
======================================================

.. automodule:: umbra.components.factory.componentsManagerUi.models

Module Attributes
-----------------

.. attribute:: umbra.components.factory.componentsManagerUi.models.LOGGER

Classes
-------

.. autoclass:: ComponentsModel
	:show-inheritance:
	:members:

